package Task::BeLike::SARTAK;
use strict;
use warnings;
our $VERSION = '0.05';

1;

__END__

=head1 NAME

Task::BeLike::SARTAK

=head1 DESCRIPTION

See the F<Makefile.PL> in this distribution.

=head1 AUTHOR

Shawn M Moore C<code@sartak.org>

=head1 COPYRIGHT

Copyright 2011-2013 Shawn M Moore.

This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.

=cut

